# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.identity_response import IdentityResponse


class TestIdentityResponse(unittest.TestCase):
    """IdentityResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> IdentityResponse:
        """Test IdentityResponse
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `IdentityResponse`
        """
        model = IdentityResponse()
        if include_optional:
            return IdentityResponse(
                accounts = [
                    moneykit.models.account_identity.AccountIdentity(
                        account_id = '', 
                        account_type = '', 
                        name = '', 
                        nickname = '', 
                        account_mask = '', 
                        balances = null, 
                        original_id = '', 
                        closed = True, 
                        owners = [
                            moneykit.models.owner.Owner(
                                names = [
                                    ''
                                    ], 
                                addresses = [
                                    moneykit.models.address.Address(
                                        city = '', 
                                        country = '', 
                                        postal_code = '', 
                                        region = '', 
                                        street = '', 
                                        primary = True, )
                                    ], 
                                phone_numbers = [
                                    moneykit.models.phone_number.PhoneNumber(
                                        number = '', 
                                        primary = True, 
                                        type = null, )
                                    ], 
                                emails = [
                                    moneykit.models.email.Email(
                                        address = '', 
                                        primary = True, )
                                    ], )
                            ], )
                    ],
                link = moneykit.models.link_common.LinkCommon(
                    link_id = '', 
                    institution_id = '', 
                    institution_name = '', 
                    institution_avatar = '', 
                    state = null, 
                    error_code = null, 
                    last_synced_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    provider = null, 
                    link_tags = [
                        ''
                        ], 
                    tags = [
                        ''
                        ], 
                    webhook = '', 
                    products = null, 
                    available_products = [
                        'accounts'
                        ], )
            )
        else:
            return IdentityResponse(
                accounts = [
                    moneykit.models.account_identity.AccountIdentity(
                        account_id = '', 
                        account_type = '', 
                        name = '', 
                        nickname = '', 
                        account_mask = '', 
                        balances = null, 
                        original_id = '', 
                        closed = True, 
                        owners = [
                            moneykit.models.owner.Owner(
                                names = [
                                    ''
                                    ], 
                                addresses = [
                                    moneykit.models.address.Address(
                                        city = '', 
                                        country = '', 
                                        postal_code = '', 
                                        region = '', 
                                        street = '', 
                                        primary = True, )
                                    ], 
                                phone_numbers = [
                                    moneykit.models.phone_number.PhoneNumber(
                                        number = '', 
                                        primary = True, 
                                        type = null, )
                                    ], 
                                emails = [
                                    moneykit.models.email.Email(
                                        address = '', 
                                        primary = True, )
                                    ], )
                            ], )
                    ],
                link = moneykit.models.link_common.LinkCommon(
                    link_id = '', 
                    institution_id = '', 
                    institution_name = '', 
                    institution_avatar = '', 
                    state = null, 
                    error_code = null, 
                    last_synced_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    provider = null, 
                    link_tags = [
                        ''
                        ], 
                    tags = [
                        ''
                        ], 
                    webhook = '', 
                    products = null, 
                    available_products = [
                        'accounts'
                        ], ),
        )
        """

    def testIdentityResponse(self):
        """Test IdentityResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
