# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictStr
from pydantic import Field
from moneykit.models.link_products import LinkProducts
from moneykit.models.product import Product
from moneykit.models.provider import Provider
from moneykit.models.public_link_error import PublicLinkError
from moneykit.models.public_link_state import PublicLinkState

try:
    from typing import Self
except ImportError:
    from typing_extensions import Self


class LinkCommon(BaseModel):
    """
    LinkCommon
    """  # noqa: E501

    link_id: StrictStr = Field(description="The unique ID for this link.")
    institution_id: StrictStr = Field(
        description="The unique ID for the institution this link is connected to."
    )
    institution_name: StrictStr = Field(
        description="The institution name this link is connected to."
    )
    institution_avatar: StrictStr = Field(
        description="An avatar image for the link's institution."
    )
    state: PublicLinkState
    error_code: Optional[PublicLinkError] = None
    last_synced_at: Optional[datetime] = Field(
        default=None,
        description="(Deprecated) An ISO-8601 timestamp indicating the last time that the link was updated.",
    )
    provider: Provider
    link_tags: Optional[List[StrictStr]] = None
    tags: Optional[List[StrictStr]] = None
    webhook: Optional[StrictStr] = Field(
        default=None, description="The webhook url assigned to this link."
    )
    products: LinkProducts
    available_products: List[Product]
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = [
        "link_id",
        "institution_id",
        "institution_name",
        "institution_avatar",
        "state",
        "error_code",
        "last_synced_at",
        "provider",
        "link_tags",
        "tags",
        "webhook",
        "products",
        "available_products",
    ]

    model_config = {"populate_by_name": True, "validate_assignment": True}

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of LinkCommon from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
                "additional_properties",
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of products
        if self.products:
            _dict["products"] = self.products.to_dict()
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of LinkCommon from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "link_id": obj.get("link_id"),
                "institution_id": obj.get("institution_id"),
                "institution_name": obj.get("institution_name"),
                "institution_avatar": obj.get("institution_avatar"),
                "state": obj.get("state"),
                "error_code": obj.get("error_code"),
                "last_synced_at": obj.get("last_synced_at"),
                "provider": obj.get("provider"),
                "link_tags": obj.get("link_tags"),
                "tags": obj.get("tags"),
                "webhook": obj.get("webhook"),
                "products": LinkProducts.from_dict(obj.get("products"))
                if obj.get("products") is not None
                else None,
                "available_products": obj.get("available_products"),
            }
        )
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj
